@@ -36,9 +36,9 @@ public:
     BrightnessControlConfig(QObject*, const QVariantList&);
     virtual ~BrightnessControlConfig();
 
-    virtual void save();
-    virtual void load();
-    virtual QList< QPair< QString, QWidget* > > buildUi();
+    void save() Q_DECL_OVERRIDE;
+    void load() Q_DECL_OVERRIDE;
+    QList< QPair< QString, QWidget* > > buildUi() Q_DECL_OVERRIDE;
 
 private:
     QSlider *m_slider;
