@@ -38,15 +38,15 @@ public:
     virtual ~KeyboardBrightnessControl() = default;
 
 protected:
-    virtual void onProfileUnload();
-    virtual void onWakeupFromIdle();
-    virtual void onIdleTimeout(int msec);
-    virtual void onProfileLoad();
-    virtual void triggerImpl(const QVariantMap& args);
-    virtual bool isSupported();
+    void onProfileUnload() Q_DECL_OVERRIDE;
+    void onWakeupFromIdle() Q_DECL_OVERRIDE;
+    void onIdleTimeout(int msec) Q_DECL_OVERRIDE;
+    void onProfileLoad() Q_DECL_OVERRIDE;
+    void triggerImpl(const QVariantMap& args) Q_DECL_OVERRIDE;
+    bool isSupported() Q_DECL_OVERRIDE;
 
 public:
-    virtual bool loadAction(const KConfigGroup& config);
+    bool loadAction(const KConfigGroup& config) Q_DECL_OVERRIDE;
 
 public Q_SLOTS:
     void onBrightnessChangedFromBackend(const BrightnessLogic::BrightnessInfo &brightnessInfo, BackendInterface::BrightnessControlType type);
