@@ -32,9 +32,9 @@ public:
     PowerDevilDPMSActionConfig(QObject* parent, const QVariantList&);
     virtual ~PowerDevilDPMSActionConfig();
 
-    virtual void save();
-    virtual void load();
-    virtual QList< QPair< QString, QWidget* > > buildUi();
+    void save() Q_DECL_OVERRIDE;
+    void load() Q_DECL_OVERRIDE;
+    QList< QPair< QString, QWidget* > > buildUi() Q_DECL_OVERRIDE;
 
 private:
     QSpinBox *m_spinBox;
