@@ -514,7 +514,7 @@ bool Core::emitBatteryChargePercentNotification(int currentPercent, int previous
     if (b && !b->isPowerSupply()) {
         // if you leave the device out of reach or it has not been initialized yet
         // it won't be "there" and report 0%, don't show anything in this case
-        if (!b->isPresent()) {
+        if (!b->isPresent() || b->chargeState() != Battery::Discharging) {
             return false;
         }
 
@@ -828,11 +828,10 @@ int Core::currentChargePercent() const
 void Core::onResumingFromIdle()
 {
     // Wake up the actions in which an idle action was triggered
-    auto i = m_pendingResumeFromIdleActions.begin();
-    while (i != m_pendingResumeFromIdleActions.end()) {
-        (*i)->onWakeupFromIdle();
-        i = m_pendingResumeFromIdleActions.erase(i);
-    }
+    std::for_each(m_pendingResumeFromIdleActions.cbegin(), m_pendingResumeFromIdleActions.cend(),
+        std::mem_fn(&PowerDevil::Action::onWakeupFromIdle));
+
+    m_pendingResumeFromIdleActions.clear();
 }
 
 void Core::onNotificationTimeout()
