@@ -101,7 +101,7 @@ void ActivityWidget::load()
         m_ui->alwaysActionBox->addItem(QIcon::fromTheme("system-suspend-hibernate"),
                                        i18n("Hibernate"), (uint)SuspendSession::ToDiskMode);
     }
-    m_ui->alwaysActionBox->addItem(QIcon::fromTheme("system-shutdown"), i18n("Shutdown"), (uint)SuspendSession::ShutdownMode);
+    m_ui->alwaysActionBox->addItem(QIcon::fromTheme("system-shutdown"), i18n("Shut down"), (uint)SuspendSession::ShutdownMode);
 
     m_ui->actLikeComboBox->clear();
 
@@ -110,7 +110,7 @@ void ActivityWidget::load()
     m_ui->actLikeComboBox->addItem(QIcon::fromTheme("battery-low"), i18n("PC running on low battery"), "LowBattery");
 
     bool hasBattery = false;
-    foreach (const Solid::Device &device, Solid::Device::listFromType(Solid::DeviceInterface::Battery, QString())) {
+    Q_FOREACH (const Solid::Device &device, Solid::Device::listFromType(Solid::DeviceInterface::Battery, QString())) {
         const Solid::Battery *b = qobject_cast<const Solid::Battery*> (device.asDeviceInterface(Solid::DeviceInterface::Battery));
         if (b->type() == Solid::Battery::PrimaryBattery || b->type() == Solid::Battery::UpsBattery) {
             hasBattery = false;
@@ -121,7 +121,7 @@ void ActivityWidget::load()
     m_ui->actLikeRadio->setVisible(hasBattery);
     m_ui->actLikeComboBox->setVisible(hasBattery);
 
-    foreach (const QString &activity, m_activityConsumer->activities()) {
+    Q_FOREACH (const QString &activity, m_activityConsumer->activities()) {
         if (activity == m_activity) {
             continue;
         }
@@ -197,7 +197,7 @@ void ActivityWidget::save()
 
 void ActivityWidget::setChanged()
 {
-    emit changed(true);
+    Q_EMIT changed(true);
 }
 
 
