@@ -30,7 +30,7 @@ public:
     virtual ~ErrorOverlay();
 
 protected:
-    bool eventFilter(QObject *object, QEvent *event);
+    bool eventFilter(QObject *object, QEvent *event) Q_DECL_OVERRIDE;
 
 private:
     void reposition();
