@@ -124,6 +124,8 @@ void GeneralPage::fillUi()
 
     connect(BatteryCriticalCombo, SIGNAL(currentIndexChanged(int)), SLOT(changed()));
 
+    connect(pausePlayersCheckBox, SIGNAL(stateChanged(int)), SLOT(changed()));
+
     if (!hasPowerSupplyBattery) {
         BatteryCriticalLabel->hide();
         BatteryCriticalCombo->hide();
@@ -150,6 +152,8 @@ void GeneralPage::load()
     lowPeripheralSpin->setValue(PowerDevilSettings::peripheralBatteryLowLevel());
 
     BatteryCriticalCombo->setCurrentIndex(BatteryCriticalCombo->findData(PowerDevilSettings::batteryCriticalAction()));
+
+    pausePlayersCheckBox->setChecked(PowerDevilSettings::pausePlayersOnSuspend());
 }
 
 void GeneralPage::configureNotifications()
@@ -165,6 +169,8 @@ void GeneralPage::save()
 
     PowerDevilSettings::setBatteryCriticalAction(BatteryCriticalCombo->itemData(BatteryCriticalCombo->currentIndex()).toInt());
 
+    PowerDevilSettings::setPausePlayersOnSuspend(pausePlayersCheckBox->checkState() == Qt::Checked);
+
     PowerDevilSettings::self()->save();
 
     // Notify Daemon
@@ -187,8 +193,9 @@ void GeneralPage::onServiceRegistered(const QString& service)
 {
     Q_UNUSED(service);
 
-    if (!m_errorOverlay.isNull()) {
-        m_errorOverlay.data()->deleteLater();
+    if (m_errorOverlay) {
+        m_errorOverlay->deleteLater();
+        m_errorOverlay = nullptr;
     }
 }
 
@@ -196,8 +203,8 @@ void GeneralPage::onServiceUnregistered(const QString& service)
 {
     Q_UNUSED(service);
 
-    if (!m_errorOverlay.isNull()) {
-        m_errorOverlay.data()->deleteLater();
+    if (m_errorOverlay) {
+        m_errorOverlay->deleteLater();
     }
 
     m_errorOverlay = new ErrorOverlay(this, i18n("The Power Management Service appears not to be running.\n"
